@@ -5,7 +5,7 @@
 @LastEditors: ChenXiaolei
 @Description: 文件操作相关接口
 """
-from seven_studio.handlers.seven_base import *
+from seven_studio.handlers.studio_base import *
 
 from seven_studio.models.db_models.file.file_storage_path_model import *
 from seven_studio.models.db_models.file.file_resource_model import *
@@ -16,7 +16,7 @@ from seven_studio.models.seven_model import InvokeResult
 from seven_studio.libs.file.ks3 import *
 
 
-class GetStoragePathListHandler(SevenBaseHandler):
+class GetStoragePathListHandler(StudioBaseHandler):
     """
     @description: 获取存储配置列表
     """
@@ -39,7 +39,7 @@ class GetStoragePathListHandler(SevenBaseHandler):
         self.reponse_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
 
 
-class GetStoragePathDataHandler(SevenBaseHandler):
+class GetStoragePathDataHandler(StudioBaseHandler):
     """
     @description: 获取存储配置
     @param {type} 
@@ -61,7 +61,7 @@ class GetStoragePathDataHandler(SevenBaseHandler):
         self.reponse_json_success(p_dict)
 
 
-class SaveStoragePathHandler(SevenBaseHandler):
+class SaveStoragePathHandler(StudioBaseHandler):
     """
     @description: 保存存储配置
     """
@@ -117,7 +117,7 @@ class SaveStoragePathHandler(SevenBaseHandler):
         self.reponse_json_success(file_storage_path)
 
 
-class DeleteStoragePathHandler(SevenBaseHandler):
+class DeleteStoragePathHandler(StudioBaseHandler):
     """
     @description: 删除存储配置
     """
@@ -139,7 +139,7 @@ class DeleteStoragePathHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class GetResourceListHandler(SevenBaseHandler):
+class GetResourceListHandler(StudioBaseHandler):
     """
     @description: 获取文件配置列表
     """
@@ -162,7 +162,7 @@ class GetResourceListHandler(SevenBaseHandler):
         self.reponse_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
 
 
-class GetResourceInfoHandler(SevenBaseHandler):
+class GetResourceInfoHandler(StudioBaseHandler):
     """
     @description: 获取文件配置
     """
@@ -181,7 +181,7 @@ class GetResourceInfoHandler(SevenBaseHandler):
         self.reponse_json_success(p_dict)
 
 
-class SaveResourceHandler(SevenBaseHandler):
+class SaveResourceHandler(StudioBaseHandler):
     """
     @description: 保存文件配置
     """
@@ -225,7 +225,7 @@ class SaveResourceHandler(SevenBaseHandler):
         self.reponse_json_success(file_resource)
 
 
-class DeleteResourceHandler(SevenBaseHandler):
+class DeleteResourceHandler(StudioBaseHandler):
     """
     @description: 删除资源
     """
@@ -247,7 +247,7 @@ class DeleteResourceHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class GetRestrictListHandler(SevenBaseHandler):
+class GetRestrictListHandler(StudioBaseHandler):
     """
     @description: 获取上传限制
     """
@@ -283,7 +283,7 @@ class GetRestrictListHandler(SevenBaseHandler):
         self.reponse_json_success(page_dict)
 
 
-class SaveRestrictHandler(SevenBaseHandler):
+class SaveRestrictHandler(StudioBaseHandler):
     """
     @description: SaveRestrict
     """
@@ -371,7 +371,7 @@ class SaveRestrictHandler(SevenBaseHandler):
         self.reponse_json_success(file_restrict)
 
 
-class DeleteRestrictHandler(SevenBaseHandler):
+class DeleteRestrictHandler(StudioBaseHandler):
     """
     @description: DeleteRestrict
     """
@@ -393,7 +393,7 @@ class DeleteRestrictHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class GetWaterImageListHandler(SevenBaseHandler):
+class GetWaterImageListHandler(StudioBaseHandler):
     """
     @description: 获取水印图片列表
     """
@@ -416,7 +416,7 @@ class GetWaterImageListHandler(SevenBaseHandler):
         self.reponse_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
 
 
-class GetWaterImageDataHandler(SevenBaseHandler):
+class GetWaterImageDataHandler(StudioBaseHandler):
     """
     @description: 获取水印图片
     """
@@ -435,7 +435,7 @@ class GetWaterImageDataHandler(SevenBaseHandler):
         self.reponse_json_success(p_dict)
 
 
-class SaveWaterImageHandler(SevenBaseHandler):
+class SaveWaterImageHandler(StudioBaseHandler):
     """
     @description: 保存图片水印
     """
@@ -479,7 +479,7 @@ class SaveWaterImageHandler(SevenBaseHandler):
         self.reponse_json_success(file_water_image)
 
 
-class DeleteWaterImageHandler(SevenBaseHandler):
+class DeleteWaterImageHandler(StudioBaseHandler):
     """
     @description: 删除水印图
     """
@@ -501,7 +501,7 @@ class DeleteWaterImageHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class GetHistoryListHandler(SevenBaseHandler):
+class GetHistoryListHandler(StudioBaseHandler):
     """
     @description: 获取文件历史
     """
@@ -524,7 +524,7 @@ class GetHistoryListHandler(SevenBaseHandler):
         self.reponse_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
 
 
-class DeleteHistoryHandler(SevenBaseHandler):
+class DeleteHistoryHandler(StudioBaseHandler):
     """
     @description: 删除文件历史记录
     """
