@@ -5,7 +5,7 @@
 @LastEditors: ChenXiaolei
 @Description: power 用户权限相关接口
 """
-from seven_studio.handlers.seven_base import *
+from seven_studio.handlers.studio_base import *
 from seven_studio.utils.dict import *
 
 from seven_studio.models.db_models.product.product_info_model import *
@@ -19,7 +19,7 @@ from seven_studio.models.seven_model import InvokeResult
 from seven_studio.models.power_model import *
 
 
-class GetUserInfoHandler(SevenBaseHandler):
+class GetUserInfoHandler(StudioBaseHandler):
     """
     @description: 获取当前用户信息
     """
@@ -43,7 +43,7 @@ class GetUserInfoHandler(SevenBaseHandler):
         self.reponse_json_success(curr_info)
 
 
-class GetUserProductListHandler(SevenBaseHandler):
+class GetUserProductListHandler(StudioBaseHandler):
     """
     @description: 获取用户产品列表
     """
@@ -177,7 +177,7 @@ class GetUserProductListHandler(SevenBaseHandler):
         return InvokeResult()
 
 
-class FocusPasswordHandler(SevenBaseHandler):
+class FocusPasswordHandler(StudioBaseHandler):
     """
     @description: 强制修改密码弹窗
     """
@@ -199,7 +199,7 @@ class FocusPasswordHandler(SevenBaseHandler):
         self.reponse_custom(invoke_result)
 
 
-class FocusChangeUserPwHandler(SevenBaseHandler):
+class FocusChangeUserPwHandler(StudioBaseHandler):
     """
     @description: 强制修改密码
     """
@@ -233,7 +233,7 @@ class FocusChangeUserPwHandler(SevenBaseHandler):
         self.reponse_custom(invoke_result)
 
 
-class ChangeCurrUserPwHandler(SevenBaseHandler):
+class ChangeCurrUserPwHandler(StudioBaseHandler):
     """
     @description: 修改密码
     """
@@ -267,7 +267,7 @@ class ChangeCurrUserPwHandler(SevenBaseHandler):
         self.reponse_custom(invoke_result)
 
 
-class GetRoleListHandler(SevenBaseHandler):
+class GetRoleListHandler(StudioBaseHandler):
     """
     @description: 角色列表
     """
@@ -293,7 +293,7 @@ class GetRoleListHandler(SevenBaseHandler):
         self.reponse_json_success(role_dict_list)
 
 
-class GetRoleUserListHandler(SevenBaseHandler):
+class GetRoleUserListHandler(StudioBaseHandler):
     """
     @description: 角色用户列表
     """
@@ -371,7 +371,7 @@ class GetRoleUserListHandler(SevenBaseHandler):
         self.reponse_json_success(page_data)
 
 
-class GetUserRoleListHandler(SevenBaseHandler):
+class GetUserRoleListHandler(StudioBaseHandler):
     """
     @description: 用户角色列表
     """
@@ -451,7 +451,7 @@ class GetUserRoleListHandler(SevenBaseHandler):
         self.reponse_json_success(page_data)
 
 
-class SaveUserHandler(SevenBaseHandler):
+class SaveUserHandler(StudioBaseHandler):
     """
     @description: 保存用户
     """
@@ -522,7 +522,7 @@ class SaveUserHandler(SevenBaseHandler):
         self.reponse_json_success(result)
 
 
-class SaveCurrUserHandler(SevenBaseHandler):
+class SaveCurrUserHandler(StudioBaseHandler):
     """
     @description: 保存用户
     """
@@ -562,7 +562,7 @@ class SaveCurrUserHandler(SevenBaseHandler):
         self.reponse_json_success(user_info)
 
 
-class GetUserListHandler(SevenBaseHandler):
+class GetUserListHandler(StudioBaseHandler):
     """
     @description: 用户列表
     """
@@ -588,7 +588,7 @@ class GetUserListHandler(SevenBaseHandler):
         self.reponse_json_success(user_dict_list)
 
 
-class SaveRoleHandler(SevenBaseHandler):
+class SaveRoleHandler(StudioBaseHandler):
     """
     @description: 修改角色
     """
@@ -652,7 +652,7 @@ class SaveRoleHandler(SevenBaseHandler):
         self.reponse_json_success(result.__dict__)
 
 
-class RemoveRoleUserHandler(SevenBaseHandler):
+class RemoveRoleUserHandler(StudioBaseHandler):
     """
     @description: 删除用户角色
     """
@@ -684,7 +684,7 @@ class RemoveRoleUserHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class DeleteRoleHandler(SevenBaseHandler):
+class DeleteRoleHandler(StudioBaseHandler):
     """
     @description: 删除角色
     """
@@ -711,7 +711,7 @@ class DeleteRoleHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class DeleteUserHandler(SevenBaseHandler):
+class DeleteUserHandler(StudioBaseHandler):
     """
     @description: 删除用户
     """
@@ -747,7 +747,7 @@ class DeleteUserHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class ModifyUserStatusHandler(SevenBaseHandler):
+class ModifyUserStatusHandler(StudioBaseHandler):
     """
     @description: 更新用户状态
     """
@@ -788,7 +788,7 @@ class ModifyUserStatusHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class ResetUserPasswordHandler(SevenBaseHandler):
+class ResetUserPasswordHandler(StudioBaseHandler):
     """
     @description: 重置密码
     """
@@ -826,7 +826,7 @@ class ResetUserPasswordHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class ResetUserFaildLoginCountHandler(SevenBaseHandler):
+class ResetUserFaildLoginCountHandler(StudioBaseHandler):
     """
     @description: 登录失败重置
     """
@@ -860,7 +860,7 @@ class ResetUserFaildLoginCountHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class RemoveUserAllRoleHandler(SevenBaseHandler):
+class RemoveUserAllRoleHandler(StudioBaseHandler):
     """
     @description: 收回权限
     """
@@ -891,7 +891,7 @@ class RemoveUserAllRoleHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class CopyUserRoleHandler(SevenBaseHandler):
+class CopyUserRoleHandler(StudioBaseHandler):
     """
     @description: 复制权限
     """
