@@ -1,7 +1,7 @@
 """
 @Author: HuangJingCan
 @Date: 2020-04-15 09:56:24
-@LastEditTime: 2020-12-10 10:37:55
+@LastEditTime: 2020-12-10 17:19:53
 @LastEditors: ChenXiaolei
 @Description: 权限角色栏目相关
 """
@@ -451,6 +451,8 @@ class PowerModel():
             self.add_role_menu(role_info.RoleID, menu_id_list)
 
         result = DictUtil.auto_mapper(RoleUserDto(), role_info.__dict__)
+        result.RoleUserIds = user_id_list
+        result.RoleMenuIds = menu_id_list
         result.IsAdd=is_add
         return result
 
